@@ -3,7 +3,8 @@ import time
 from enum import Enum
 
 from cognite.client.data_classes._base import *
-from cognite.client.data_classes.transformations.common import RawTable, TransformationDestination
+from cognite.client.data_classes.transformations._alphatypes import AlphaDataModelInstances
+from cognite.client.data_classes.transformations.common import RawTable, SequenceRows, TransformationDestination
 
 
 class TransformationJobStatus(str, Enum):
@@ -189,7 +190,7 @@ class TransformationJob(CogniteResource):
                 >>> from cognite.client import CogniteClient
                 >>> c = CogniteClient()
                 >>>
-                >>> async def run_succesive_transformations():
+                >>> async def run_successive_transformations():
                 >>>     job1 = c.transformations.run(id = 1, wait = False)
                 >>>     job2 = c.transformations.run(id = 2, wait = False)
                 >>>     await job1.wait_async()
@@ -197,7 +198,7 @@ class TransformationJob(CogniteResource):
                 >>>     if TransformationJobStatus.FAILED not in [job1.status, job2.status]:
                 >>>         c.transformations.run(id = 3, wait = False)
                 >>>
-                >>> ensure_future(run_succesive_transformations())
+                >>> ensure_future(run_successive_transformations())
 
             wait transformation for 5 minutes and do something if still running:
 
@@ -205,7 +206,7 @@ class TransformationJob(CogniteResource):
                 >>> from cognite.client import CogniteClient
                 >>> c = CogniteClient()
                 >>>
-                >>> async def run_succesive_transformations():
+                >>> async def run_successive_transformations():
                 >>>     job = c.transformations.run(id = 1, wait = False)
                 >>>     await job.wait_async(timeout = 5.0*60)
                 >>>     if job.status == TransformationJobStatus.FAILED:
@@ -215,7 +216,7 @@ class TransformationJob(CogniteResource):
                 >>>     else:
                 >>>         # do something if job is still running
                 >>>
-                >>> ensure_future(run_succesive_transformations())
+                >>> ensure_future(run_successive_transformations())
         """
         self.update()
         if timeout is None:
@@ -240,6 +241,12 @@ class TransformationJob(CogniteResource):
             if instance.destination.get("type") == "raw":
                 snake_dict.pop("type")
                 instance.destination = RawTable(**snake_dict)
+            elif instance.destination.get("type") == "data_model_instances":
+                snake_dict.pop("type")
+                instance.destination = AlphaDataModelInstances(**snake_dict)
+            elif instance.destination.get("type") == "sequence_rows":
+                snake_dict.pop("type")
+                instance.destination = SequenceRows(**snake_dict)
             else:
                 instance.destination = TransformationDestination(**snake_dict)
         return instance
